summaryrefslogtreecommitdiffstats
path: root/ksirc/boundscheckingarray.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksirc/boundscheckingarray.h')
-rw-r--r--ksirc/boundscheckingarray.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksirc/boundscheckingarray.h b/ksirc/boundscheckingarray.h
index a8a29ca1..92b528b7 100644
--- a/ksirc/boundscheckingarray.h
+++ b/ksirc/boundscheckingarray.h
@@ -20,9 +20,9 @@
#define __boundscheckingarray__
#include <assert.h>
#include <qvaluevector.h>
/* I wish QValueVector would check bounds upon extraction.. */
template <typename T, const unsigned int size>
class BoundsCheckingArray
@@ -51,9 +51,9 @@ public:
return m_data[ index ];
}
- QValueVector<T> toValueVector() const
+ TQValueVector<T> toValueVector() const
{
- QValueVector<T> vector( size );
+ TQValueVector<T> vector( size );
for ( unsigned int i = 0; i < size; ++i )
vector[ i ] = m_data[ i ];
return vector;
@@ -20,9 +20,9 @@
#define __boundscheckingarray__
#include <assert.h>
-#include <qvaluevector.h>
+#include <tqvaluevector.h>
-/* I wish QValueVector would check bounds upon extraction.. */
+/* I wish TQValueVector would check bounds upon extraction.. */
template <typename T, const unsigned int size>
class BoundsCheckingArray